@@ -15,6 +15,6 @@ public class {{ targetFile }} {
      * Called when you Submit your code
      */
     public static {% if targetMethodReturn == "" %}void{% else %}{{ targetMethodReturn }}{% endif %} {{ targetMethod }}({{ targetMethodArgs }}) {
-        {% if targetMethodReturn != "" %}return null;{% endif %}
+        {% if targetMethodReturn != "" %}return {{ targetMethodReturnValue }};{% endif %}
     }
 }
